cordova.define("cordova-plugin-comall-umeng.umeng", function(require, exports, module) {
/**
 * 友盟社会化插件
 */
var exec = require("cordova/exec");

var umeng = function() {};

/**
 * 分享
 * @param title {String} 分享标题
 * @param content {String} 分享内容
 * @param pic {String} 分享图片url
 * @param url {String} 分享内容跳转链接
 * @param successCallback {Function} 分享成功回调，参数为分享平台
 */
umeng.share = function(title, content, pic, url, successCallback) {
    exec(successCallback, null, "UmengPlugin", "share", [
        title,
        content,
        pic,
        url
    ]);
};

/**
 * 分享携带分享平台类型
 * @param title {String} 分享标题
 * @param content {String} 分享内容
 * @param pic {String} 分享图片url
 * @param url {String} 分享内容跳转链接
 * @param type {String} sina //新浪
                         wxsession //微信聊天
                         wxtimeline //微信朋友圈
                         qq //QQ聊天页面
                         qzone //qq空间
 * @param successCallback {Function} 分享成功回调，参数为分享平台
 * @param sinaLinkCard {Boolean} 新浪分享内容使用LinkCard
 */
umeng.shareByType = function(title, content, pic, url, type, successCallback, sinaLinkCard) {
    exec(successCallback, null, "UmengPlugin", "shareByType", [
        title,
        content,
        pic,
        url,
        type,
        sinaLinkCard || false
    ]);
};

/**
 * 分享携带分享平台类型(只分享图片)
 * @param pic {String} 分享图片url
 * @param type {String} sina //新浪
                         wxsession //微信聊天
                         wxtimeline //微信朋友圈
                         qq //QQ聊天页面
                         qzone //qq空间
 * @param successCallback {Function} 分享成功回调，参数为分享平台
 */
umeng.shareImageByType = function(pic, type, successCallback) {
    exec(successCallback, null, "UmengPlugin", "shareImageByType", [pic, type]);
};

/**
 * 联合登录
 * @param type {String} 平台类型 QQ:qq, 微博:sina, 微信:wechat
 * @param success {Function} 成功回调，返回json字符串{"uid":"uid","name":"name"}
 * @param error {Function} 失败回调，返回错误信息
 */
umeng.login = function(type, success, error) {
    function successProxies() {
        umeng.lastLoginPlatform = type;
        success.apply(this, arguments);
    }
    exec(successProxies, error, "UmengPlugin", "login", [type]);
};

/**
 * 退出登录(取消授权)
 * @param type {String} 平台类型 QQ:qq, 微博:sina, 微信:wechat
 * @param success {Function} 成功回调, 返回 0成功 1指定平台未登录 -1退出登录失败
 * @param error {Function} 失败回调
 */
umeng.logout = function(type, success, error) {
    var _type = type || umeng.lastLoginPlatform;
    exec(success, error, "UmengPlugin", "logout", [_type]);
};

/**
 * 检查应用是否已安装
 * @param type {String} 平台类型 QQ:qq, 微博:sina, 微信:wechat
 * @param success {Function} 成功回调
 * @param error {Function} 失败回调，返回错误信息
 */
umeng.checkAppInstalled = function(type, success, error) {
    // if(type == 'wechat'){
    //     if(window.wechatPay && window.wechatPay.checkAppInstalled){
    //         window.wechatPay.checkAppInstalled(success,error);
    //         return;
    //     }else {
    //         setTimeout(function(){
    //             error.call(this, false);
    //         },100)
    //     }
    // }
    exec(success, error, "UmengPlugin", "checkAppInstalled", [type]);
};

module.exports = umeng;

});
