cordova.define("cordova-plugin-comall-umspay.umspay", function(require, exports, module) {
var noop = function() {};
var isString = function(arg) {
    return typeof arg === "string";
};

var umspay = {
    /**
     * 支付渠道
     */
    CHANNEL: {
        WEIXIN: "01",
        ALIPAY: "02",
        UMSPAY: "03"
    },
    /**
     * 状态码
     */
    CODE: {
        ERR_OK: "0000",
        ERR_COMM: "9999",
        ERR_USER_CANCEL: "1000",
        ERR_PARARM: "1001",
        ERR_SENT_FAILED: "1002",
        ERR_CLIENT_UNINSTALL: "1003",
        ERR_ORDER_PROCESS: "2001",
        ERR_ORDER_DUPLICATE: "2002",
        ERR_PAY_FAIL: "2003",
        ERR_AUTH_DENIED: "005",
        ERR_UNSUPPORT: "006",
        ERR_BAN: "007"
    },

    /**
     * 插件测试方法
     */
    ping: function() {
        cordova.exec(
            function() {
                console.log("插件存活");
            },
            noop,
            "umspay",
            "ping",
            []
        );
    },

    /**
     * 发起支付
     *
     * @param {string} payChannel 支付渠道
     * @param {string} payData 支付数据
     * @param {function(<PayResult>)} success 成功回调
     * @param {function(<PayResult>)} failure 失败回调
     * @example
     * window.umspay.pay(window.umspay.CHANNEL.ALIPAY, payData, () => {}, res => {alert(res);});
     */
    pay: function(payChannel, payData, success, failure) {
        success = success || noop;
        failure = failure || noop;

        if (!isString(payChannel) || !isString(payData)) {
            console.warn("[umspay] 参数类型错误.");
            return;
        }

        cordova.exec(success, failure, "umspay", "pay", [payChannel, payData]);
    }
};

module.exports = umspay;

});
